.. meta::
   :description: Reference documentation responsible AI toolbox PyTorch datasets

.. _dataset-reference:

########
Datasets
########

The following datasets are useful for training, testing, and benchmarking neural networks on: common corruptions, out-of-distribution generalization tasks, and on other robustness-probing data.

********************
CIFAR-Based Datasets
********************
.. currentmodule:: rai_toolbox.datasets

.. autosummary::
   :toctree: generated/

   CIFAR10C
   CIFAR100C
   CIFAR10P1


***********************
ImageNet-Based Datasets
***********************
.. currentmodule:: rai_toolbox.datasets

.. autosummary::
   :toctree: generated/

   ImageNet
   ImageNetM10
   RestrictedImageNet
